@@ -13,12 +13,9 @@ def render(template, context):
         raise TemplateError('top level keys of context must follow '
                             '/[a-zA-Z_][a-zA-Z0-9_]*/')
     full_context = {'now': fromNow('0 seconds', None)}
-    full_context.update(builtins.build(full_context))
+    full_context.update(builtins.build())
     full_context.update(context)
     rv = renderValue(template, full_context)
     if rv is DeleteMarker:
         return None
-    if callable(rv):
-        raise TemplateError(('$eval {} doesn\'t get any arguments '
-                             'in template').format(template['$eval']))
     return rv
