@@ -8,13 +8,13 @@ class BuiltinError(JSONTemplateError):
     pass
 
 
-def build(context):
+def build():
     builtins = {}
 
-    def builtin(name, variadic=None, argument_tests=None, minArgs=None):
+    def builtin(name, variadic=None, argument_tests=None, minArgs=None, needs_context=False):
         def wrap(fn):
             if variadic:
-                def invoke(*args):
+                def invoke(context, *args):
                     if minArgs:
                         if len(args) < minArgs:
                             raise BuiltinError(
@@ -23,23 +23,31 @@ def build(context):
                     for arg in args:
                         if not variadic(arg):
                             raise BuiltinError('invalid arguments to builtin: {}'.format(name))
+                    if needs_context is True:
+                        return fn(context, *args)
                     return fn(*args)
 
             elif argument_tests:
-                def invoke(*args):
+                def invoke(context, *args):
                     if len(args) != len(argument_tests):
                         raise BuiltinError('invalid arguments to builtin: {}'.format(name))
                     for t, arg in zip(argument_tests, args):
                         if not t(arg):
                             raise BuiltinError('invalid arguments to builtin: {}'.format(name))
+                    if needs_context is True:
+                        return fn(context, *args)
                     return fn(*args)
 
             else:
-                def invoke(*args):
+                def invoke(context, *args):
+                    if needs_context is True:
+                        return fn(context, *args)
                     return fn(*args)
 
+            invoke._jsone_builtin = True
             builtins[name] = invoke
             return fn
+
         return wrap
 
     def is_number(v):
@@ -96,8 +104,8 @@ def build(context):
     def lstrip(s):
         return s.lstrip()
 
-    @builtin('fromNow', variadic=is_string, minArgs=1)
-    def fromNow_builtin(offset, reference=None):
+    @builtin('fromNow', variadic=is_string, minArgs=1, needs_context=True)
+    def fromNow_builtin(context, offset, reference=None):
         return fromNow(offset, reference or context.get('now'))
 
     @builtin('typeof', argument_tests=[anything])
@@ -117,8 +125,8 @@ def build(context):
         elif callable(v):
             return 'function'
 
-    @builtin('defined', argument_tests=[is_string])
-    def defined(s):
+    @builtin('defined', argument_tests=[is_string], needs_context=True)
+    def defined(context, s):
         if s not in context:
             return False
         else:
